==> hs-webkit-0.12.1p1.tgz: lib/ghc/webkit-0.12.1/register.sh <==
#!/bin/sh
echo 'name: webkit
version: 0.12.1
id: webkit-0.12.1-8fd70647b288ba6d9007a625f78030f4

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: WebKit is a web content engine, derived from KHTML and KJS from KDE, and
             used primarily in Apple'\''s Safari browser.  It is made to be embedded in
             other applications, such as mail readers, or web browsers.
             It is able to display content such as HTML, SVG, XML, and others. It also
             supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and more.
category: Graphics
author: Cjacker Huang, Andy Stewart, Axel Simon
pkgpath: www/hs-webkit
exposed: True
exposed-modules: Graphics.UI.Gtk.WebKit.CacheModel
                 Graphics.UI.Gtk.WebKit.Download
                 Graphics.UI.Gtk.WebKit.GeolocationPolicyDecision
                 Graphics.UI.Gtk.WebKit.HitTestResult
                 Graphics.UI.Gtk.WebKit.NetworkRequest
                 Graphics.UI.Gtk.WebKit.NetworkResponse
                 Graphics.UI.Gtk.WebKit.SecurityOrigin
                 Graphics.UI.Gtk.WebKit.SoupAuthDialog
                 Graphics.UI.Gtk.WebKit.WebBackForwardList
                 Graphics.UI.Gtk.WebKit.WebDatabase
                 Graphics.UI.Gtk.WebKit.WebDataSource
                 Graphics.UI.Gtk.WebKit.WebFrame
                 Graphics.UI.Gtk.WebKit.WebHistoryItem
                 Graphics.UI.Gtk.WebKit.WebInspector
                 Graphics.UI.Gtk.WebKit.WebNavigationAction
                 Graphics.UI.Gtk.WebKit.WebPolicyDecision
                 Graphics.UI.Gtk.WebKit.WebResource
                 Graphics.UI.Gtk.WebKit.WebSettings Graphics.UI.Gtk.WebKit.WebView
                 Graphics.UI.Gtk.WebKit.WebWindowFeatures
hidden-modules: Graphics.UI.Gtk.WebKit.Internal
                Graphics.UI.Gtk.WebKit.Types Graphics.UI.Gtk.WebKit.Signals
import-dirs: /usr/local/lib/ghc/webkit-0.12.1
library-dirs: /usr/local/lib/ghc/webkit-0.12.1 /usr/local/lib
              /usr/X11R6/lib
hs-libraries: HSwebkit-0.12.1
extra-libraries: webkitgtk-1.0 gtk-x11-2.0 gdk-x11-2.0
                 pangocairo-1.0 Xext Xinerama Xi Xrandr Xcursor Xcomposite Xdamage
                 Xfixes atk-1.0 cairo pixman-1 pthread-stubs GL png xcb-shm
                 xcb-render xcb Xrender X11 gdk_pixbuf-2.0 pangoft2-1.0 pango-1.0 m
                 fontconfig expat freetype z soup-2.4 gio-2.0 gobject-2.0
                 javascriptcoregtk-1.0 glib-2.0 intl iconv
extra-ghci-libraries:
include-dirs: /usr/local/include/webkitgtk-1.0
              /usr/local/include/gtk-2.0 /usr/local/lib/gtk-2.0/include
              /usr/local/include/pango-1.0 /usr/local/include/gio-unix-2.0/
              /usr/X11R6/include /usr/local/include/cairo
              /usr/local/include/atk-1.0 /usr/X11R6/include/pixman-1
              /usr/include/dev/pci/drm /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/libpng /usr/X11R6/include/freetype2
              /usr/local/include/libsoup-2.4 /usr/local/include/libxml2
              /usr/local/include /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include
includes:
depends: array-0.3.0.2-f538acad67d0b6696484da310d5949cf
         base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
         cairo-0.12.0-44277534ae49f2172d58677127edb6a9
         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
         glib-0.12.0-58f533cd92d47371ecb1bc085e466fee
         gtk-0.12.0-a50d05ba8d8174638f22f1a87b2772d4
         haskell98-1.1.0.1-3ce559675b118e85a39def472ca9857c
         mtl-2.0.1.0-3e464329054b7660133198d73c31aca5
         pango-0.12.0-f0cbda7e6c393357b5fb10b5c7dd11ab
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-webkit-0.12.1/html/webkit.haddock
haddock-html: /usr/local/share/doc/hs-webkit-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-webkit-0.12.4p1.tgz: lib/ghc/webkit-0.12.4/register.sh <==
#!/bin/sh
echo 'name: webkit
version: 0.12.4
id: webkit-0.12.4-067cf414537d8e9082edb83db354153e

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the Webkit library.
description: WebKit is a web content engine, derived from KHTML and KJS from KDE, and
             used primarily in Apple'\''s Safari browser.  It is made to be embedded in
             other applications, such as mail readers, or web browsers.
             It is able to display content such as HTML, SVG, XML, and others. It also
             supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and more.
category: Graphics
author: Cjacker Huang, Andy Stewart, Axel Simon
pkgpath: www/hs-webkit
exposed: True
exposed-modules: Graphics.UI.Gtk.WebKit.CacheModel
                 Graphics.UI.Gtk.WebKit.Download
                 Graphics.UI.Gtk.WebKit.GeolocationPolicyDecision
                 Graphics.UI.Gtk.WebKit.HitTestResult
                 Graphics.UI.Gtk.WebKit.NetworkRequest
                 Graphics.UI.Gtk.WebKit.NetworkResponse
                 Graphics.UI.Gtk.WebKit.SecurityOrigin
                 Graphics.UI.Gtk.WebKit.SoupAuthDialog
                 Graphics.UI.Gtk.WebKit.WebBackForwardList
                 Graphics.UI.Gtk.WebKit.WebDatabase
                 Graphics.UI.Gtk.WebKit.WebDataSource
                 Graphics.UI.Gtk.WebKit.WebFrame
                 Graphics.UI.Gtk.WebKit.WebHistoryItem
                 Graphics.UI.Gtk.WebKit.WebInspector
                 Graphics.UI.Gtk.WebKit.WebNavigationAction
                 Graphics.UI.Gtk.WebKit.WebPolicyDecision
                 Graphics.UI.Gtk.WebKit.WebResource
                 Graphics.UI.Gtk.WebKit.WebSettings Graphics.UI.Gtk.WebKit.WebView
                 Graphics.UI.Gtk.WebKit.WebWindowFeatures
hidden-modules: Graphics.UI.Gtk.WebKit.Internal
                Graphics.UI.Gtk.WebKit.Types Graphics.UI.Gtk.WebKit.Signals
trusted: False
import-dirs: /usr/local/lib/ghc/webkit-0.12.4
library-dirs: /usr/local/lib/ghc/webkit-0.12.4 /usr/local/lib
              /usr/X11R6/lib
hs-libraries: HSwebkit-0.12.4
extra-libraries: webkitgtk-1.0 gtk-x11-2.0 gdk-x11-2.0
                 pangocairo-1.0 Xrender Xinerama Xi Xrandr Xcursor Xcomposite
                 Xdamage Xfixes X11 Xext atk-1.0 cairo gdk_pixbuf-2.0 pangoft2-1.0
                 pango-1.0 m fontconfig expat freetype z soup-2.4 gio-2.0
                 gobject-2.0 javascriptcoregtk-1.0 glib-2.0 intl iconv
extra-ghci-libraries:
include-dirs: /usr/local/include/webkitgtk-1.0
              /usr/local/include/gtk-2.0 /usr/local/lib/gtk-2.0/include
              /usr/local/include/pango-1.0 /usr/local/include/gio-unix-2.0/
              /usr/X11R6/include /usr/local/include/cairo
              /usr/local/include/atk-1.0 /usr/X11R6/include/pixman-1
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/libpng
              /usr/local/include/harfbuzz /usr/X11R6/include/freetype2
              /usr/local/include/libsoup-2.4 /usr/local/include/libxml2
              /usr/local/include /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include
includes:
depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
         cairo-0.12.3.1-cf457dfe25292e09fa980e3d9b270c9e
         glib-0.12.3.1-802d98cfe9a88c3ac80f8e30d4b86d4a
         gtk-0.12.3.1-28c6e9e8b6ee0308cb54914f61306856
         pango-0.12.3-c793132a2b917d90a03e1195fab8c726
hugs-options:
cc-options:
ld-options: "-Wl,-rpath-link,/usr/X11R6/lib"
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-webkit-0.12.4/html/webkit.haddock
haddock-html: /usr/local/share/doc/hs-webkit-0.12.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
